clear all

% Costanti fisiche
global g = 9.81;
global rho = 1e3;
global mu = 1e-3;
global D = 0.10;
global L = 15;
global es = 0.001;
global k = 0.5; % Imbocco

global r = 0.4; % Raggio della cisterna

function z = bernoulli(H, Q)
	global g;
	global rho;
	global mu;
	global D;
	global L;
	global es;
	global k;
	global r;

	h = H ./ (pi .* r^2); 
	% Calcolo la velocità
	v = hspeed(Q, D);
	% Calcolo il carico totale
	H12 = h - v.^2/(2.*g);
	% Calcolo la viscosità cinematica
	nu = mu ./ rho;
	% Calcolo il numero di Reynolds
	Re = Reynolds(v, D, nu);
	% Calcolo il coefficiente di attrito
	f = churchill(Re, es ./ D);
	% Calcolo le perdite di carico distribuite
	WD = loss_l(f, D, L, v, g);
	% Calcolo le perdite di carico concentrate
	WC = loss_k(k, v, g);
	% Calcolo il valore della funzione
	z = H12 - WD - WC;
end


function dH = f(H, t)
	f1 = @(Q) (bernoulli(H, Q));
	Q = fsolve(f1, 0.001);
	dH = -Q;
end

% Condizioni al contorno
H0 = 4 .* pi .* r.^2;
t = linspace(0, 120);
H = lsode(@f, H0, t);

plot(t, H, 'linewidth', 2);